@@ -1,7 +1,6 @@
-extern crate patch;
-
-use patch::{Patch, Line, parse};
+//! Demonstrates how to apply a parsed diff to a file
 
+use patch::{Line, Patch};
 
 fn apply(diff: Patch, old: &str) -> String {
     let old_lines = old.lines().collect::<Vec<&str>>();
@@ -15,17 +14,14 @@ fn apply(diff: Patch, old: &str) -> String {
         old_line += hunk.old_range.count;
         for line in hunk.lines {
             match line {
-                Line::Add(s) | Line::Context(s) =>
-                    out.push(s),
-                Line::Remove(_) =>
-                    {},
+                Line::Add(s) | Line::Context(s) => out.push(s),
+                Line::Remove(_) => {}
             }
         }
     }
     out.join("\n")
 }
 
-
 static LAO: &'static str = "\
 The Way that can be told of is not the eternal Way;
 The name that can be named is not the eternal name.
@@ -40,7 +36,6 @@ But after they are produced,
   they have different names.
 ";
 
-
 static RAW_DIFF: &'static str = "\
 --- lao 2002-02-21 23:30:39.942229878 -0800
 +++ tzu 2002-02-21 23:30:50.442260588 -0800
@@ -63,9 +58,8 @@ static RAW_DIFF: &'static str = "\
 +The door of all subtleties!
 ";
 
-
 fn main() {
-    let diff = parse(RAW_DIFF).unwrap();
+    let diff = Patch::from_single(RAW_DIFF).unwrap();
     let new = apply(diff, LAO);
     println!("should be tzu:\n\n{}", new);
 }
